==> telepathy-glib-0.12.7.tgz: include/telepathy-1.0/telepathy-glib/_gen/error-str.h <==
#define TP_ERROR_STR_NETWORK_ERROR "org.freedesktop.Telepathy.Error.NetworkError"
#define TP_ERROR_STR_NOT_IMPLEMENTED "org.freedesktop.Telepathy.Error.NotImplemented"
#define TP_ERROR_STR_INVALID_ARGUMENT "org.freedesktop.Telepathy.Error.InvalidArgument"
#define TP_ERROR_STR_NOT_AVAILABLE "org.freedesktop.Telepathy.Error.NotAvailable"
#define TP_ERROR_STR_PERMISSION_DENIED "org.freedesktop.Telepathy.Error.PermissionDenied"
#define TP_ERROR_STR_DISCONNECTED "org.freedesktop.Telepathy.Error.Disconnected"
#define TP_ERROR_STR_INVALID_HANDLE "org.freedesktop.Telepathy.Error.InvalidHandle"
#define TP_ERROR_STR_CHANNEL_BANNED "org.freedesktop.Telepathy.Error.Channel.Banned"
#define TP_ERROR_STR_CHANNEL_FULL "org.freedesktop.Telepathy.Error.Channel.Full"
#define TP_ERROR_STR_CHANNEL_INVITE_ONLY "org.freedesktop.Telepathy.Error.Channel.InviteOnly"
#define TP_ERROR_STR_NOT_YOURS "org.freedesktop.Telepathy.Error.NotYours"
#define TP_ERROR_STR_CANCELLED "org.freedesktop.Telepathy.Error.Cancelled"
#define TP_ERROR_STR_AUTHENTICATION_FAILED "org.freedesktop.Telepathy.Error.AuthenticationFailed"
#define TP_ERROR_STR_ENCRYPTION_NOT_AVAILABLE "org.freedesktop.Telepathy.Error.EncryptionNotAvailable"
#define TP_ERROR_STR_ENCRYPTION_ERROR "org.freedesktop.Telepathy.Error.EncryptionError"
#define TP_ERROR_STR_CERT_NOT_PROVIDED "org.freedesktop.Telepathy.Error.Cert.NotProvided"
#define TP_ERROR_STR_CERT_UNTRUSTED "org.freedesktop.Telepathy.Error.Cert.Untrusted"
#define TP_ERROR_STR_CERT_EXPIRED "org.freedesktop.Telepathy.Error.Cert.Expired"
#define TP_ERROR_STR_CERT_NOT_ACTIVATED "org.freedesktop.Telepathy.Error.Cert.NotActivated"
#define TP_ERROR_STR_CERT_FINGERPRINT_MISMATCH "org.freedesktop.Telepathy.Error.Cert.FingerprintMismatch"
#define TP_ERROR_STR_CERT_HOSTNAME_MISMATCH "org.freedesktop.Telepathy.Error.Cert.HostnameMismatch"
#define TP_ERROR_STR_CERT_SELF_SIGNED "org.freedesktop.Telepathy.Error.Cert.SelfSigned"
#define TP_ERROR_STR_CERT_REVOKED "org.freedesktop.Telepathy.Error.Cert.Revoked"
#define TP_ERROR_STR_CERT_INSECURE "org.freedesktop.Telepathy.Error.Cert.Insecure"
#define TP_ERROR_STR_CERT_INVALID "org.freedesktop.Telepathy.Error.Cert.Invalid"
#define TP_ERROR_STR_CERT_LIMIT_EXCEEDED "org.freedesktop.Telepathy.Error.Cert.LimitExceeded"
#define TP_ERROR_STR_NOT_CAPABLE "org.freedesktop.Telepathy.Error.NotCapable"
#define TP_ERROR_STR_OFFLINE "org.freedesktop.Telepathy.Error.Offline"
#define TP_ERROR_STR_CHANNEL_KICKED "org.freedesktop.Telepathy.Error.Channel.Kicked"
#define TP_ERROR_STR_BUSY "org.freedesktop.Telepathy.Error.Busy"
#define TP_ERROR_STR_NO_ANSWER "org.freedesktop.Telepathy.Error.NoAnswer"
#define TP_ERROR_STR_DOES_NOT_EXIST "org.freedesktop.Telepathy.Error.DoesNotExist"
#define TP_ERROR_STR_TERMINATED "org.freedesktop.Telepathy.Error.Terminated"
#define TP_ERROR_STR_CONNECTION_REFUSED "org.freedesktop.Telepathy.Error.ConnectionRefused"
#define TP_ERROR_STR_CONNECTION_FAILED "org.freedesktop.Telepathy.Error.ConnectionFailed"
#define TP_ERROR_STR_CONNECTION_LOST "org.freedesktop.Telepathy.Error.ConnectionLost"
#define TP_ERROR_STR_ALREADY_CONNECTED "org.freedesktop.Telepathy.Error.AlreadyConnected"
#define TP_ERROR_STR_CONNECTION_REPLACED "org.freedesktop.Telepathy.Error.ConnectionReplaced"
#define TP_ERROR_STR_REGISTRATION_EXISTS "org.freedesktop.Telepathy.Error.RegistrationExists"
#define TP_ERROR_STR_SERVICE_BUSY "org.freedesktop.Telepathy.Error.ServiceBusy"
#define TP_ERROR_STR_RESOURCE_UNAVAILABLE "org.freedesktop.Telepathy.Error.ResourceUnavailable"
#define TP_ERROR_STR_WOULD_BREAK_ANONYMITY "org.freedesktop.Telepathy.Error.WouldBreakAnonymity"
#define TP_ERROR_STR_NOT_YET "org.freedesktop.Telepathy.Error.NotYet"

==> telepathy-glib-0.14.5p0.tgz: include/telepathy-1.0/telepathy-glib/_gen/error-str.h <==
#define TP_ERROR_STR_NETWORK_ERROR "org.freedesktop.Telepathy.Error.NetworkError"
#define TP_ERROR_STR_NOT_IMPLEMENTED "org.freedesktop.Telepathy.Error.NotImplemented"
#define TP_ERROR_STR_INVALID_ARGUMENT "org.freedesktop.Telepathy.Error.InvalidArgument"
#define TP_ERROR_STR_NOT_AVAILABLE "org.freedesktop.Telepathy.Error.NotAvailable"
#define TP_ERROR_STR_PERMISSION_DENIED "org.freedesktop.Telepathy.Error.PermissionDenied"
#define TP_ERROR_STR_DISCONNECTED "org.freedesktop.Telepathy.Error.Disconnected"
#define TP_ERROR_STR_INVALID_HANDLE "org.freedesktop.Telepathy.Error.InvalidHandle"
#define TP_ERROR_STR_CHANNEL_BANNED "org.freedesktop.Telepathy.Error.Channel.Banned"
#define TP_ERROR_STR_CHANNEL_FULL "org.freedesktop.Telepathy.Error.Channel.Full"
#define TP_ERROR_STR_CHANNEL_INVITE_ONLY "org.freedesktop.Telepathy.Error.Channel.InviteOnly"
#define TP_ERROR_STR_NOT_YOURS "org.freedesktop.Telepathy.Error.NotYours"
#define TP_ERROR_STR_CANCELLED "org.freedesktop.Telepathy.Error.Cancelled"
#define TP_ERROR_STR_AUTHENTICATION_FAILED "org.freedesktop.Telepathy.Error.AuthenticationFailed"
#define TP_ERROR_STR_ENCRYPTION_NOT_AVAILABLE "org.freedesktop.Telepathy.Error.EncryptionNotAvailable"
#define TP_ERROR_STR_ENCRYPTION_ERROR "org.freedesktop.Telepathy.Error.EncryptionError"
#define TP_ERROR_STR_CERT_NOT_PROVIDED "org.freedesktop.Telepathy.Error.Cert.NotProvided"
#define TP_ERROR_STR_CERT_UNTRUSTED "org.freedesktop.Telepathy.Error.Cert.Untrusted"
#define TP_ERROR_STR_CERT_EXPIRED "org.freedesktop.Telepathy.Error.Cert.Expired"
#define TP_ERROR_STR_CERT_NOT_ACTIVATED "org.freedesktop.Telepathy.Error.Cert.NotActivated"
#define TP_ERROR_STR_CERT_FINGERPRINT_MISMATCH "org.freedesktop.Telepathy.Error.Cert.FingerprintMismatch"
#define TP_ERROR_STR_CERT_HOSTNAME_MISMATCH "org.freedesktop.Telepathy.Error.Cert.HostnameMismatch"
#define TP_ERROR_STR_CERT_SELF_SIGNED "org.freedesktop.Telepathy.Error.Cert.SelfSigned"
#define TP_ERROR_STR_CERT_REVOKED "org.freedesktop.Telepathy.Error.Cert.Revoked"
#define TP_ERROR_STR_CERT_INSECURE "org.freedesktop.Telepathy.Error.Cert.Insecure"
#define TP_ERROR_STR_CERT_INVALID "org.freedesktop.Telepathy.Error.Cert.Invalid"
#define TP_ERROR_STR_CERT_LIMIT_EXCEEDED "org.freedesktop.Telepathy.Error.Cert.LimitExceeded"
#define TP_ERROR_STR_NOT_CAPABLE "org.freedesktop.Telepathy.Error.NotCapable"
#define TP_ERROR_STR_OFFLINE "org.freedesktop.Telepathy.Error.Offline"
#define TP_ERROR_STR_CHANNEL_KICKED "org.freedesktop.Telepathy.Error.Channel.Kicked"
#define TP_ERROR_STR_BUSY "org.freedesktop.Telepathy.Error.Busy"
#define TP_ERROR_STR_NO_ANSWER "org.freedesktop.Telepathy.Error.NoAnswer"
#define TP_ERROR_STR_DOES_NOT_EXIST "org.freedesktop.Telepathy.Error.DoesNotExist"
#define TP_ERROR_STR_TERMINATED "org.freedesktop.Telepathy.Error.Terminated"
#define TP_ERROR_STR_CONNECTION_REFUSED "org.freedesktop.Telepathy.Error.ConnectionRefused"
#define TP_ERROR_STR_CONNECTION_FAILED "org.freedesktop.Telepathy.Error.ConnectionFailed"
#define TP_ERROR_STR_CONNECTION_LOST "org.freedesktop.Telepathy.Error.ConnectionLost"
#define TP_ERROR_STR_ALREADY_CONNECTED "org.freedesktop.Telepathy.Error.AlreadyConnected"
#define TP_ERROR_STR_CONNECTION_REPLACED "org.freedesktop.Telepathy.Error.ConnectionReplaced"
#define TP_ERROR_STR_REGISTRATION_EXISTS "org.freedesktop.Telepathy.Error.RegistrationExists"
#define TP_ERROR_STR_SERVICE_BUSY "org.freedesktop.Telepathy.Error.ServiceBusy"
#define TP_ERROR_STR_RESOURCE_UNAVAILABLE "org.freedesktop.Telepathy.Error.ResourceUnavailable"
#define TP_ERROR_STR_WOULD_BREAK_ANONYMITY "org.freedesktop.Telepathy.Error.WouldBreakAnonymity"
#define TP_ERROR_STR_NOT_YET "org.freedesktop.Telepathy.Error.NotYet"
#define TP_ERROR_STR_REJECTED "org.freedesktop.Telepathy.Error.Rejected"
#define TP_ERROR_STR_PICKED_UP_ELSEWHERE "org.freedesktop.Telepathy.Error.PickedUpElsewhere"
#define TP_ERROR_STR_SERVICE_CONFUSED "org.freedesktop.Telepathy.Error.ServiceConfused"
#define TP_ERROR_STR_CONFUSED "org.freedesktop.Telepathy.Error.Confused"
#define TP_ERROR_STR_SOFTWARE_UPGRADE_REQUIRED "org.freedesktop.Telepathy.Error.SoftwareUpgradeRequired"
#define TP_ERROR_STR_EMERGENCY_CALLS_NOT_SUPPORTED "org.freedesktop.Telepathy.Error.EmergencyCallsNotSupported"
#define TP_ERROR_STR_INSUFFICIENT_BALANCE "org.freedesktop.Telepathy.Error.InsufficientBalance"
